# img2planes

Convert any image to Amiga C bitplanes and associated palette.

Uses PIL (Pillow) to read the image input.

## Prerequisites
 - Python 3

Plus any library you might need for Pillow, e.g. zlib and libjpeg.
